netapp_ontap.models.consistency_group_nas API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.consistency_group_nas`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class ConsistencyGroupNasSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the ConsistencyGroupNas object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `cifs: ConsistencyGroupConsistencyGroupsVolumesNasCifs GET POST PATCH`

    The cifs field of the consistency_group_nas.

  `export_policy: ConsistencyGroupExportPolicy GET POST PATCH`

    The policy associated with volumes to export them for protocol access.

  `gid: Size GET POST`

    The UNIX group ID of the volume. Valid in POST or PATCH.

  `junction_parent: ConsistencyGroupConsistencyGroupsVolumesNasJunctionParent GET POST`

    The junction_parent field of the consistency_group_nas.

  `path: str GET POST`

    The fully-qualified path in the owning SVM's namespace at which the volume is mounted. The path is case insensitive and must be unique within an SVM's namespace. Path must begin with '/' and must not end with '/'. Only one volume can be mounted at any given junction path. An empty path in POST creates an unmounted volume. An empty path in PATCH deactivates and unmounts the volume. Taking a volume offline or restricted state removes its junction path. This attribute is reported in GET only when the volume is mounted.

    Example: /user/my_volume

  `security_style: str GET POST`

    Security style associated with the volume. Valid in POST or PATCH.
    mixed ‐ Mixed-style security
    ntfs ‐ NTFS/WIndows-style security
    unified ‐ Unified-style security, unified UNIX, NFS and CIFS permissions
    unix ‐ UNIX-style security.

    Valid choices:

    - mixed
    - ntfs
    - unified
    - unix
  `uid: Size GET POST`

    The UNIX user ID of the volume. Valid in POST or PATCH.

  `unix_permissions: Size GET POST`

    UNIX permissions to be viewed as an octal number, consisting of 4 digits derived by adding up bits 4 (read), 2 (write), and 1 (execute). First digit selects the set user ID (4), set group ID (2), and sticky (1) attributes. Second digit selects permission for the owner of the file. Third selects permissions for other users in the same group while the fourth selects permissions for other users not in the group. Valid in POST or PATCH. For security style "mixed" or "unix", the default setting is 0755 in octal (493 in decimal) and for security style "ntfs", the default setting is 0000. In cases where only owner, group, and other permissions are given (as in 755, representing the second, third and fourth digit), the first digit is assumed to be zero.

    Example: 493